@@ -20,7 +20,8 @@ parse_roxygen <- function(roxygen) {
   had_warning <- FALSE
   parsed <- withCallingHandlers(
     {
-      parsed <- as.character(tools::parse_Rd(connection, fragment = TRUE), deparse = FALSE)
+      parsed <- tools::parse_Rd(connection, fragment = TRUE) %>%
+        as.character(deparse = FALSE)
       if (had_warning) {
         roxygen_remove_extra_brace(parsed)
       } else {
@@ -83,25 +84,29 @@ roxygen_remove_extra_brace <- function(parsed) {
         while (worth_trying_to_remove_brace) {
           # remove brace
           brace <- which(parsed == "}")
-          if (length(brace) > 0) {
+          if (length(brace) > 0L) {
             parsed <- parsed[-last(brace)]
           }
           linebreak <- which(parsed == "\n")
-          if (length(linebreak) > 0) {
+          if (length(linebreak) > 0L) {
             parsed <- parsed[-last(linebreak)]
           }
           # try if can be parsed (need remve dontrun)
           worth_trying_to_remove_brace <- rlang::with_handlers(
             {
-              parse(text = gsub("^\\\\[[:alpha:]]+", "", parsed)) # this will error informatively
-              FALSE # if parsing succeeds, we can stop tryint to remove brace and move on with parsed
+              # this will error informatively
+              parse(text = gsub("^\\\\[[:alpha:]]+", "", parsed))
+              # if parsing succeeds, we can stop tryint to remove brace and move
+              # on with parsed
+              FALSE
             },
             error = function(...) {
               # continue if braces are left, otherwise give up
               if (any(last(parsed) %in% c("}", "\n"))) {
                 TRUE
               } else {
-                # this will error informatively. If not, outer loop will fail informatively
+                # this will error informatively. If not, outer loop will fail
+                # informatively
                 parse(text = gsub("^\\\\[[:alpha:]]+", "", parsed_))
                 FALSE
               }
@@ -109,7 +114,8 @@ roxygen_remove_extra_brace <- function(parsed) {
           )
         }
       } else {
-        parse(text = gsub("^\\\\[[:alpha:]]*", "", parsed_)) # this will error informatively
+        # this will error informatively
+        parse(text = gsub("^\\\\[[:alpha:]]*", "", parsed_))
       }
       parsed
     }
@@ -124,11 +130,15 @@ roxygen_remove_extra_brace <- function(parsed) {
 #' `remove_roxygen_mask()` when there are no characters to escape.
 #' @keywords internal
 emulate_rd <- function(roxygen) {
-  example_type <- gsub("^#'(\\s|\t)*@examples(If)?(\\s|\t)*(.*)", "examples\\2", roxygen[1])
+  example_type <- gsub(
+    "^#'(\\s|\t)*@examples(If)?(\\s|\t)*(.*)", "examples\\2", roxygen[1L]
+  )
   if (needs_rd_emulation(roxygen)) {
     roxygen <- c(
       "#' Example",
-      gsub("^#'(\\s|\t)*@examples(If)?(\\s|\t)*(.*)", "#' @examples \\4", roxygen),
+      gsub(
+        "^#'(\\s|\t)*@examples(If)?(\\s|\t)*(.*)", "#' @examples \\4", roxygen
+      ),
       "x <- 1"
     )
     roxygen <- gsub("(^#)[^']", "#' #", roxygen)
@@ -136,11 +146,10 @@ emulate_rd <- function(roxygen) {
     text <- roxygen2::roc_proc_text(
       roxygen2::rd_roclet(),
       paste(roxygen, collapse = "\n")
-    )[[1]]$get_section("examples") %>%
-      as.character() %>%
-      .[-1]
+    )[[1L]]$get_section("examples")
+    text <- as.character(text)[-1L]
     text <- c(
-      if (grepl("^#'(\\s|\t)*@examples(\\s|\t)*$", roxygen[2])) "",
+      if (grepl("^#'(\\s|\t)*@examples(\\s|\t)*$", roxygen[2L])) "",
       text
     )
   } else {
