@@ -170,7 +170,7 @@ cache_by_expression <- function(text,
   # was removed via parse, same as it is in cache_by_expression) and add the
   # base indention.
   expressions[expressions$parent == 0L & expressions$token != "COMMENT" & !expressions$stylerignore, "text"] %>%
-    map(~ cache_write(.x, transformers = transformers, more_specs))
+    map(cache_write, transformers = transformers, more_specs)
 }
 
 
