@@ -1,10 +1,9 @@
-context("various helpers")
+
 
 test_that("can construct and print vertical", {
-  expect_error(construct_vertical(c("1 + 1", "nw")), NA)
-  capture.output(
-    expect_error(construct_vertical(c("1 + 1", "nw")) %>% print(), NA)
-  )
+  expect_snapshot({
+    construct_vertical(c("1 + 1", "nw"))
+  })
 })
 
 
@@ -13,7 +12,9 @@ test_that("file types can be asserted", {
 })
 
 test_that("can lookup tokens", {
-  expect_error(lookup_new_special(), NA)
+  expect_snapshot({
+    lookup_new_special()
+  })
 })
 
 test_that("can extend non-comment", {
